/******************************************************************************
 *
 * Copyright (c) 2019, the jupyter-fs authors.
 *
 * This file is part of the jupyter-fs library, distributed under the terms of
 * the Apache License 2.0.  The full license can be found in the LICENSE file.
 *
 */
import * as React from "react";
import { IFSOptions, IFSResource } from "./filesystem";
declare class Template {
    template: string;
    pattern: RegExp;
    constructor(template: string);
    substitute(dict: {
        [key: string]: string;
    }): string;
    tokens(): string[];
}
export declare class DoubleBraceTemplate extends Template {
    pattern: RegExp;
}
export declare function askRequired(specs: IFSResource[]): boolean;
export declare class AskDialog<P extends AskDialog.IProps = AskDialog.IProps, S extends AskDialog.IState = AskDialog.IState> extends React.Component<P, S> {
    static displayName: string;
    constructor(props: P, options: IFSOptions);
    render(): React.JSX.Element;
    protected _form(): React.JSX.Element;
    protected _formInner(): React.JSX.Element[][];
    protected _inputs(url: string): React.ReactNodeArray;
    protected _onChange(url: string): (event: React.ChangeEvent<HTMLInputElement>) => void;
    protected _onClickVisiblity(url: string, key: string): () => void;
    protected _onMouseDownVisibility(event: React.MouseEvent<HTMLButtonElement>): void;
    protected _onOpen(): void;
    protected _onClose(): void;
    protected _onSubmit(event: React.FormEvent<HTMLFormElement>): Promise<void>;
    protected _setValue(url: string, key: string, value: string): void;
    protected _toggleVisibility(url: string, key: string): void;
}
/**
 * A namespace for AskDialog statics.
 */
export declare namespace AskDialog {
    /**
     * The input props for an AskDialog component
     */
    interface IProps {
        handleClose: () => void;
        handleSubmit: (values: {
            [url: string]: {
                [key: string]: string;
            };
        }) => void;
        options: IFSOptions;
        resources: IFSResource[];
    }
    /**
     * The initial state for a new AskDialog
     */
    const initialState: ({ open, options, }: {
        open?: boolean;
        options: IFSOptions;
    }) => {
        open: boolean;
        options: {
            _addServerside?: boolean;
            cache?: boolean;
            verbose?: boolean;
            writtenVersion?: string;
        };
        values: {
            [url: string]: {
                [key: string]: string;
            };
        };
        visibility: {
            [url: string]: {
                [key: string]: string;
            };
        };
    };
    /**
     * The state for an AskDialog component
     */
    type IState = ReturnType<typeof initialState>;
}
export {};
