/******************************************************************************
 *
 * Copyright (c) 2019, the jupyter-fs authors.
 *
 * This file is part of the jupyter-fs library, distributed under the terms of
 * the Apache License 2.0.  The full license can be found in the LICENSE file.
 *
 */
import { JupyterFrontEnd } from "@jupyterlab/application";
import { DocumentRegistry } from "@jupyterlab/docregistry";
import { IDisposable } from "@lumino/disposable";
import { Content } from "@tree-finder/base";
import { JupyterClipboard } from "./clipboard";
import { TreeFinderSidebar } from "./treefinder";
import type { IFSResource } from "./filesystem";
import type { ContentsProxy } from "./contents_proxy";
import type { TreeFinderTracker } from "./treefinder";
import { ISettingRegistry } from "@jupyterlab/settingregistry";
export declare const commandNames: readonly ["copy", "cut", "delete", "open", "openWith", "paste", "refresh", "rename", "download", "create_folder", "create_file", "copyFullPath", "copyRelativePath", "restore", "toggleColumnPath", "toggleColumn"];
export declare const commandIDs: CommandIDs;
export type CommandIDs = {
    [k in typeof commandNames[number]]: string;
};
export declare function idFromResource(resource: IFSResource): string;
/**
 * Create commands that will have the same IDs indepent of settings/resources
 *
 * These commands do not need to be recreated on settings/resource updates
 */
export declare function createStaticCommands(app: JupyterFrontEnd, tracker: TreeFinderTracker, clipboard: JupyterClipboard): IDisposable;
/**
 * Create commands whose count/IDs depend on settings/resources
 */
export declare function createDynamicCommands(app: JupyterFrontEnd, tracker: TreeFinderTracker, clipboard: JupyterClipboard, resources: IFSResource[], settings?: ISettingRegistry.ISettings): Promise<IDisposable>;
export declare function getFactories(docRegistry: DocumentRegistry, widget: TreeFinderSidebar, item: Content<ContentsProxy.IJupyterContentRow>): DocumentRegistry.WidgetFactory[];
