/******************************************************************************
 *
 * Copyright (c) 2019, the jupyter-fs authors.
 *
 * This file is part of the jupyter-fs library, distributed under the terms of
 * the Apache License 2.0.  The full license can be found in the LICENSE file.
 *
 */
import { Content, ContentsModel, IContentRow } from "@tree-finder/base";
/**
 * Expand the contents nodes until path is exposed.
 *
 * This means that even if the final element of the path is a directory, its expanded state will
 * not change.
 *
 * @param contents The contents model that the path is in
 * @param path The path to expose, relative to the root (i.e. first entry matches path of root)
 */
export declare function revealPath<T extends IContentRow>(contents: ContentsModel<T>, path: string[]): Promise<Content<T>>;
/**
 * Expand the contents nodes until path is exposed, and select the node of that path.
 *
 * This means that even if the final element of the path is a directory, its expanded state will
 * not change.
 *
 * @param contents The contents model that the path is in
 * @param path The path to expose, relative to the root (i.e. first entry matches path of root)
 * @param add Whether or not to add the path to the current selection, or to replace the current selection @see TreeFinder.SelectionModel.select
 */
export declare function revealAndSelectPath<T extends IContentRow>(contents: ContentsModel<T>, path: string[], add?: boolean): Promise<Content<T>>;
/**
 * Recursively opens directories in a contents model
 *
 * @param model The contents model where directories are to be opened
 * @param path Array of directory names to be opened in order
 */
export declare function openDirRecursive<T extends IContentRow>(model: ContentsModel<T>, path: string[]): Promise<void>;
/**
 * Get the parent contents row for the given contents row.
 *
 * Note: This will cause contents API calls if any dir has been invalidated between root and the parent.
 *
 * @param child The content node's whose parent we are looking for
 * @param root The root node of the path
 */
export declare function getContentParent<T extends IContentRow>(child: Content<T>, root: Content<T>): Promise<Content<T>>;
/**
 * Get targets to use for a call to tree-finder's refresh
 *
 * @param invalidateTargets The targets that need to be refreshed
 * @param root The root node of the contents tree
 * @param targetParents Whether the parents are the ones that should be invalidated
 * @returns
 */
export declare function getRefreshTargets<T extends IContentRow>(invalidateTargets: T[], root: Content<T>, targetParents?: boolean): T[] | undefined;
/**
 * Split a "pathstr" into its drive and path components
 */
export declare function splitPathstrDrive(pathstr: string): [string, string];
