/******************************************************************************
 *
 * Copyright (c) 2019, the jupyter-fs authors.
 *
 * This file is part of the jupyter-fs library, distributed under the terms of
 * the Apache License 2.0.  The full license can be found in the LICENSE file.
 *
 */
import { URLExt } from "@jupyterlab/coreutils";
import { ServerConnection } from "@jupyterlab/services";
class FSCommBase {
    constructor() {
        this._settings = undefined;
    }
    get baseUrl() {
        return this.settings.baseUrl;
    }
    get resourcesUrl() {
        return URLExt.join(this.baseUrl, "jupyterfs/resources");
    }
    get settings() {
        if (!this._settings) {
            this._settings = ServerConnection.makeSettings();
        }
        return this._settings;
    }
}
export class FSComm extends FSCommBase {
    static get instance() {
        if (FSComm._instance === undefined) {
            FSComm._instance = new FSComm();
        }
        return FSComm._instance;
    }
    async getResourcesRequest() {
        const settings = this.settings;
        const fullUrl = this.resourcesUrl;
        return ServerConnection.makeRequest(fullUrl, { method: "GET" }, settings).then(response => {
            if (response.status !== 200) {
                return response.text().then(data => {
                    throw new ServerConnection.ResponseError(response, data);
                });
            }
            return response.json();
        });
    }
    async initResourceRequest(args) {
        const settings = this.settings;
        const fullUrl = this.resourcesUrl;
        return ServerConnection.makeRequest(fullUrl, {
            body: JSON.stringify(args),
            headers: {
                "Content-Type": "application/json",
            },
            method: "POST",
        }, settings).then(response => {
            if (response.status !== 200) {
                return response.text().then(data => {
                    throw new ServerConnection.ResponseError(response, data);
                });
            }
            return response.json();
        });
    }
}
//# sourceMappingURL=filesystem.js.map