/******************************************************************************
 *
 * Copyright (c) 2019, the jupyter-fs authors.
 *
 * This file is part of the jupyter-fs library, distributed under the terms of
 * the Apache License 2.0.  The full license can be found in the LICENSE file.
 *
 */
import { VDomModel, VDomRenderer, WidgetTracker } from "@jupyterlab/apputils";
import { ITranslator } from "@jupyterlab/translation";
import React from "react";
import type { TreeFinderSidebar } from "./treefinder";
/**
 * Status bar item to display file upload progress.
 */
export declare class FileUploadStatus extends VDomRenderer<FileUploadStatus.Model> {
    /**
     * Construct a new FileUpload status item.
     */
    constructor(opts: FileUploadStatus.IOptions);
    /**
     * Render the FileUpload status.
     */
    render(): React.JSX.Element;
    dispose(): void;
    private _onTreeFinderChange;
    private readonly translator;
    private _tracker;
}
/**
 * A namespace for FileUpload class statics.
 */
export declare namespace FileUploadStatus {
    /**
     * The VDomModel for the FileUpload renderer.
     */
    class Model extends VDomModel {
        /**
         * Construct a new model.
         */
        constructor(sidebar: TreeFinderSidebar | null);
        /**
         * The currently uploading items.
         */
        get items(): IFileUploadItem[];
        /**
         * The current file browser model.
         */
        get sidebar(): TreeFinderSidebar | null;
        set sidebar(browserModel: TreeFinderSidebar | null);
        /**
         * Handle an uploadChanged event in the filebrowser model.
         */
        private _uploadChanged;
        private _items;
        private _sidebar;
    }
    /**
     * Options for creating the upload status item.
     */
    interface IOptions {
        /**
         * The application file browser tracker.
         */
        readonly tracker: WidgetTracker<TreeFinderSidebar>;
        /**
         * The translation language bundle.
         */
        readonly translator?: ITranslator;
    }
}
/**
 * The interface for an item that is being uploaded to
 * the file system.
 */
interface IFileUploadItem {
    /**
     * The path on the filesystem that is being uploaded to.
     */
    path: string;
    /**
     * The upload progress fraction.
     */
    progress: number;
    /**
     * Whether the upload is complete.
     */
    complete: boolean;
}
export {};
