/******************************************************************************
 *
 * Copyright (c) 2019, the jupyter-fs authors.
 *
 * This file is part of the jupyter-fs library, distributed under the terms of
 * the Apache License 2.0.  The full license can be found in the LICENSE file.
 *
 */
import * as semver from "semver";
/**
 * Migrate any settings from an older version of the package
 *
 * @param settings Our settings to consider for migratation
 * @returns The modified settings object
 */
export async function migrateSettings(settings) {
    var _a, _b, _c;
    const options = settings === null || settings === void 0 ? void 0 : settings.composite.options;
    if (semver.lt((options === null || options === void 0 ? void 0 : options.writtenVersion) || "0.0.0", "0.4.0-alpha.8")) {
        // Migrate snippets to include defaults that were updated after version checked
        const defaultSnippets = ((_a = settings === null || settings === void 0 ? void 0 : settings.default("snippets")) !== null && _a !== void 0 ? _a : []);
        const defaultLabels = defaultSnippets.map(snippet => snippet.label);
        const userSnippets = ((_b = settings === null || settings === void 0 ? void 0 : settings.user.snippets) !== null && _b !== void 0 ? _b : []);
        // add the user defined snippets if they have different label to defaults
        const raw = (_c = userSnippets.reduce((combinedSnippetsArray, snippet) => {
            if (!defaultLabels.includes(snippet.label)) {
                combinedSnippetsArray.push(snippet);
            }
            return combinedSnippetsArray;
        }, [...defaultSnippets])) !== null && _c !== void 0 ? _c : [];
        await settings.set("snippets", raw);
    }
    // Update version
    await settings.set("options", {
        ...options,
        writtenVersion: settings.version,
    });
    return settings;
}
/**
 * Ensure undefined string values from settings that are required are translated to empty strings
 * @param settingsResoruce
 * @returns A filled in setting object
 */
export function unpartialResource(settingsResource) {
    return { name: "", url: "", ...settingsResource };
}
//# sourceMappingURL=settings.js.map