/******************************************************************************
 *
 * Copyright (c) 2023, the jupyter-fs authors.
 *
 * This file is part of the jupyter-fs library, distributed under the terms of
 * the Apache License 2.0.  The full license can be found in the LICENSE file.
 *
 */
import { ServerConnection } from "@jupyterlab/services";
import { ISettingRegistry } from "@jupyterlab/settingregistry";
import * as React from "react";
import type { FieldProps } from "@rjsf/utils";
/**
 * Trick to set uiSchema on our settings editor form elements.
 *
 * We use it to set the "template" to a "textarea" multiline input
 */
export declare function snippetFormRender(props: FieldProps): React.JSX.Element;
export interface RawSnippet {
    label: string;
    caption: string;
    pattern: string;
    template: string;
}
/**
 * A usage snippet specification
 */
export interface Snippet {
    /**
     * The designator to show to users
     */
    label: string;
    /**
     * An optional, longer description to show to users
     */
    caption: string;
    /**
     * A regular expression to match against the full URL of the entry, indicating if this snippet is valid for it
     */
    pattern: RegExp;
    /**
     * A template string to build up the snippet
     */
    template: string;
    /**
     * A template string to build up the snippet
     */
    type?: string;
}
/**
 * Get all the snippet specifications in the settings
 */
export declare function getSettingsSnippets(settings?: ISettingRegistry.ISettings): Snippet[];
/**
 * Gets all the snippet specifications configured on the server
 */
export declare function getServerSnippets(settings?: ServerConnection.ISettings): Promise<Snippet[]>;
/**
 * Get the snippet specifications from all sources
 */
export declare function getAllSnippets(settings?: ISettingRegistry.ISettings): Promise<Snippet[]>;
/**
 * Instantiate the template of a snippet.
 *
 * @param template The template to instantiate
 * @param resource The resource the entry belongs to
 * @param path The local path of the entry
 */
export declare function instantiateSnippet(template: string, url: string, type: string, pathstr: string): string;
