/******************************************************************************
 *
 * Copyright (c) 2019, the jupyter-fs authors.
*
* This file is part of the jupyter-fs library, distributed under the terms of
* the Apache License 2.0.  The full license can be found in the LICENSE file.
*
*/
import { ILayoutRestorer, IRouter, JupyterFrontEnd } from "@jupyterlab/application";
import { IWindowResolver, Toolbar, WidgetTracker } from "@jupyterlab/apputils";
import { IDocumentManager } from "@jupyterlab/docmanager";
import { ISettingRegistry } from "@jupyterlab/settingregistry";
import { ITranslator } from "@jupyterlab/translation";
import { Message } from "@lumino/messaging";
import { Widget } from "@lumino/widgets";
import { Content, ContentsModel, TreeFinderPanelElement } from "@tree-finder/base";
import { JupyterClipboard } from "./clipboard";
import { ContentsProxy } from "./contents_proxy";
import { DragDropWidget } from "./drag";
import { IFSResource } from "./filesystem";
import { Uploader } from "./upload";
import { MimeData } from "@lumino/coreutils";
import { Drag } from "@lumino/dragdrop";
export declare class TreeFinderTracker extends WidgetTracker<TreeFinderSidebar> {
    add(finder: TreeFinderSidebar): Promise<void>;
    remove(finder: TreeFinderSidebar): void;
    findByDrive(drive: string): TreeFinderSidebar | undefined;
    hasByDrive(drive: string): boolean;
    private _onWidgetDisposed;
    private _finders;
}
export declare class TreeFinderWidget extends DragDropWidget {
    constructor({ app, columns, rootPath, translator, settings, }: TreeFinderWidget.IOptions);
    protected move(mimeData: MimeData, target: HTMLElement): Drag.DropAction;
    protected addMimeData(handle: HTMLElement, mimeData: MimeData): void;
    protected getDragImage(handle: HTMLElement): HTMLElement | null;
    protected onGetChildren(path: string, done: Promise<void>): void;
    /**
     * Reorders the columns according to given inputs and saves to user settings
     * If `source` is dragged from left to right, it will be inserted to the right side of `dest`
     * Else if `source` is dragged from right to left, it will be inserted to the left side of `dest`
     */
    private _reorderColumns;
    draw(): void;
    refresh(): void;
    nodeInit(): Promise<void>;
    get columns(): Array<keyof ContentsProxy.IJupyterContentRow>;
    set columns(value: Array<keyof ContentsProxy.IJupyterContentRow>);
    get ready(): Promise<void>;
    get model(): ContentsModel<ContentsProxy.IJupyterContentRow> | undefined;
    get selection(): Content<ContentsProxy.IJupyterContentRow>[] | undefined;
    get selectionPathstrs(): string[] | undefined;
    /**
     * Handle the DOM events for the tree view.
     *
     * @param event - The DOM event sent to the widget.
     *
     * #### Notes
     * This method implements the DOM `EventListener` interface and is
     * called in response to events on the panel's DOM node. It should
     * not be called directly by user code.
     */
    handleEvent(event: Event): void;
    /**
     * A message handler invoked on an `'after-attach'` message.
     */
    protected onAfterAttach(msg: Message): void;
    /**
     * A message handler invoked on a `'before-detach'` message.
     */
    protected onBeforeDetach(msg: Message): void;
    private _findEventRowElement;
    selectNeighbour(diff: number, asRange: boolean): void;
    protected evtKeydown(event: KeyboardEvent): void;
    protected evtNativeDragOverEnter(event: DragEvent): void;
    protected evtNativeDragLeaveEnd(event: DragEvent): void;
    /**
     * Handle the `drop` event for the widget.
     */
    protected evtNativeDrop(event: DragEvent): void;
    contentsProxy: ContentsProxy;
    rootPath: string;
    private _columns;
    settings: ISettingRegistry.ISettings | undefined;
    uploader: Uploader | undefined;
    readonly node: TreeFinderPanelElement<ContentsProxy.IJupyterContentRow>;
    readonly translator: ITranslator;
    private _readyDelegate;
    private _trans;
    private _commands;
    private _expanding;
    private _initialLoad;
    private _currentFolder;
}
export declare namespace TreeFinderWidget {
    interface IOptions {
        app: JupyterFrontEnd;
        columns: Array<keyof ContentsProxy.IJupyterContentRow>;
        rootPath: string;
        translator?: ITranslator;
        settings?: ISettingRegistry.ISettings;
    }
}
export declare class TreeFinderSidebar extends Widget {
    constructor({ app, columns, url, type, rootPath, caption, id, settings, preferredDir, }: TreeFinderSidebar.IOptions);
    restore(): void;
    download(path: string, folder: boolean): Promise<void>;
    protected onBeforeShow(msg: any): void;
    protected onResize(msg: any): void;
    preferredDir: string | undefined;
    toolbar: Toolbar;
    treefinder: TreeFinderWidget;
    readonly url: string;
    readonly type: string;
}
export declare namespace TreeFinderSidebar {
    const tracker: TreeFinderTracker;
    const clipboard: JupyterClipboard;
    interface IOptions {
        app: JupyterFrontEnd;
        columns: Array<keyof ContentsProxy.IJupyterContentRow>;
        url: string;
        type: string;
        rootPath?: string;
        caption?: string;
        id?: string;
        translator?: ITranslator;
        settings?: ISettingRegistry.ISettings;
        preferredDir?: string;
    }
    interface ISidebarProps extends IOptions {
        manager: IDocumentManager;
        paths: JupyterFrontEnd.IPaths;
        resolver: IWindowResolver;
        restorer: ILayoutRestorer;
        router: IRouter;
        side?: string;
        settings?: ISettingRegistry.ISettings;
        type: string;
    }
    function sidebarFromResource(resource: IFSResource, props: TreeFinderSidebar.ISidebarProps): TreeFinderSidebar;
    function sidebar({ app, restorer, url, type, columns, settings, preferredDir, rootPath, caption, id, side, }: TreeFinderSidebar.ISidebarProps): TreeFinderSidebar;
    function doRename(widget: TreeFinderSidebar, oldContent: Content<ContentsProxy.IJupyterContentRow>): Promise<ContentsProxy.IJupyterContentRow>;
    /**
     * If a path entry is not in view, scroll it into view
     *
     * @param treefinder The view
     * @param pathstr The entry to show
     */
    function scrollIntoView(treefinder: TreeFinderWidget, pathstr: string): Promise<void>;
}
